@@ -2,6 +2,8 @@ from .eds import EDS
 from .utilities import FailedValidationError
 from ..can import MessageType
 
+STATE_BYTE_IDX = 0
+
 
 def parse(cob_id: int, data: list, eds_config: EDS):
     """
@@ -9,11 +11,11 @@ def parse(cob_id: int, data: list, eds_config: EDS):
 
     Arguments
     ---------
-    @:param: data: a byte string containing the heartbeat message
+    :param data: a byte string containing the heartbeat message, byte 0 is the
+    heartbeat state info.
 
-    Returns
-    -------
-    `str`: The parsed message
+    :return: the parsed message
+    :rtype: str
     """
     states = {
         0x00: "Boot-up",
@@ -21,8 +23,9 @@ def parse(cob_id: int, data: list, eds_config: EDS):
         0x05: "Operational",
         0x7F: "Pre-operational"
     }
+
     node_id = MessageType.cob_to_node(MessageType.HEARTBEAT, cob_id)
-    if len(data) < 1 or data[0] not in states:
+    if len(data) < 1 or data[STATE_BYTE_IDX] not in states:
         raise FailedValidationError(data, node_id, cob_id, __name__,
                                     "Invalid heartbeat state detected")
-    return states.get(data[0])
+    return states.get(data[STATE_BYTE_IDX])
